#
# spec file for package ghc-http-client-tls
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name http-client-tls
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.3.6.4
Release:        1.9
Summary:        Http-client backend using the connection package and tls library
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-case-insensitive-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-crypton-connection-devel
BuildRequires:  ghc-crypton-connection-prof
BuildRequires:  ghc-crypton-devel
BuildRequires:  ghc-crypton-prof
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-data-default-prof
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-exceptions-prof
BuildRequires:  ghc-http-client-devel
BuildRequires:  ghc-http-client-prof
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-http-types-prof
BuildRequires:  ghc-memory-devel
BuildRequires:  ghc-memory-prof
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-prof
BuildRequires:  ghc-network-uri-devel
BuildRequires:  ghc-network-uri-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-tls-devel
BuildRequires:  ghc-tls-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
%endif

%description
Hackage documentation generation is not reliable. For up to date documentation,
please see: <https://www.stackage.org/package/http-client-tls>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun Oct 27 2024 Peter Simons <psimons@suse.com>
- Update http-client-tls to version 0.3.6.4.
  [#]# 0.3.6.4
  * data-default-class -> data-default [#546](https://github.com/snoyberg/http-client/pull/546/files)
* Thu Aug 17 2023 Peter Simons <psimons@suse.com>
- Update http-client-tls to version 0.3.6.3.
  [#]# 0.3.6.3
  * catching up to tls 1.8.0 [#515](https://github.com/snoyberg/http-client/pull/515)
  [#]# 0.3.6.2
  * Migrate to `crypton`
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Fri Feb 11 2022 Peter Simons <psimons@suse.com>
- Update http-client-tls to version 0.3.6.1.
  [#]# 0.3.6.1
  * [#482](https://github.com/snoyberg/http-client/issues/482):
    Raise lower bound on `http-client` to fix build.
* Fri Feb  4 2022 Peter Simons <psimons@suse.com>
- Update http-client-tls to version 0.3.6.
  [#] Changelog for http-client-tls
  [#]# 0.3.6
  * Allow making requests to raw IPv6 hosts [#477](https://github.com/snoyberg/http-client/pull/477)
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Aug 31 2020 psimons@suse.com
- Update http-client-tls to version 0.3.5.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update http-client-tls to version 0.3.5.3.
  * Fix `newTlsManager` [#325](https://github.com/snoyberg/http-client/issues/325)
  * [#289](https://github.com/snoyberg/http-client/issues/289):
    Keep original `TLSSettings` when creating a `Manager` using `newTlsManagerWith`.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Jun 19 2017 psimons@suse.com
- Update to version 0.3.5.1.
* Thu Jun  8 2017 psimons@suse.com
- Update to version 0.3.5.
* Thu May 18 2017 psimons@suse.com
- Update to version 0.3.4.2 with cabal2obs.
* Sun Apr  9 2017 psimons@suse.com
- Update to version 0.3.4.1 with cabal2obs.
* Mon Feb 27 2017 psimons@suse.com
- Update to version 0.3.4 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.3.3.1 with cabal2obs.
* Tue Sep 20 2016 psimons@suse.com
- Update to version 0.2.4.1 revision 1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.2.4.1 revision 0 with cabal2obs.
* Fri Jun 17 2016 mimi.vx@gmail.com
- update to 0.2.4.1
* Sat Apr 16 2016 mimi.vx@gmail.com
- update to 0.2.4
  * Global manager
* Tue Apr 12 2016 mimi.vx@gmail.com
- update to 0.2.3
  * Exception catching cleanup
* Thu Apr 23 2015 mimi.vx@gmail.com
- initial commit
